@@ -9,7 +9,7 @@ import numpy as np
 import yaml
 import os
 import json
-from logger import logger
+from datacenter_utils.logger import logger
 
 
 def read_yaml(file_path, key='pg'):
